package cz.psika.numerist;

/**
 * Global application constants.
 *
 * @author Tomas Psika
 */
public interface Constants
{
    // Application info
    
    /**
     * Application's name.
     */
    public static final String APPNAME = "numerist";
    
    /**
     * Current version of application.
     */
    public static final String VERSION = "0.1";
    
    /**
     * Release number.
     */
    public static final String RELEASE = "2";
    
    /**
     * Open Source Software licence.
     */
    public static final String LICENSE = "GNU GPL 3";
    
    /**
     * Author(s).
     */
    public static final String AUTHORS = "Tomas Psika";
    
    /**
     * Contact.
     */
    public static final String CONTACT_EMAIL = "tomas.psika@gmail.com";

    // Configuration

    /**
     * Main configuration file where application preferences are going to be saved.
     *
     * The filename is prefix with "." on Unix systems as expected, 
     * on Windows we use first letter uppercased.
     */
    public static final String APPLICATION_CONFIG_FILENAME = "numeristrc";

    /**
     * Color configuration definitions
     */
    public static final String CONFIG_DIAGRAM_ROW_COLOR                 = "colorrowline",  
                               CONFIG_DIAGRAM_COLUMN_COLOR              = "colorrowline",
                               CONFIG_DIAGRAM_INNER_DIAGONAL_COLOR      = "colordiagonalline",
                               CONFIG_DIAGRAM_OUTER_DIAGONAL_COLOR      = "colordiagonalline0";
    
    /**
     * Mapping variable definition
     */
    public static final String CONFIG_MAPPING_SCHEMA = "nummapping";
    
    /**
     * Default mapping declaration
     */
    public static final String CONFIG_MAPPING_DEFAULT = "369";
    
    // Status codes
    
    /**
     * Success status code.
     */
    public static final int OK = 0;
    
    /**
     * Configuration error.
     */
    public static final int CONFIG_FAILURE = 1;
    
    
    // View modes
    
    /**
     * Single view mode displays at most one diagram within content panel,
     * could be dragged from thumbnail area.
     *
     * This should be default mode.
     */
    public static final boolean VIEW_MODE_SINGLE        = false;
    
    /**
     * Two diagrams could be displayed when this mode is active.
     * Diagrams could be dragged from thumbnail area, or copied and moved within
     * content panel area.
     *
     * This mode is more preferred when checking communication characteristics
     * between two persons.
     */
    public static final boolean VIEW_MODE_DUAL          = true;
    
    
    // Diagram types
    
    /**
     * Complete diagram with handlers of mouse events attached
     * and visible inside main panel area.
     */
    public static final boolean FULL_DIAGRAM           = false;
    
    /**
     * Thumbnails of diagrams are placed in the top panel.
     */
    public static final boolean THUMBNAIL               = true;

    
    // File status flags
    
    /**
     * File was modified and need saving.
     */
    public static final boolean FILE_MODIFIED           = true;
    
    /**
     * File in fine state.
     */
    public static final boolean FILE_NOT_MODIFIED       = false;
    
    
    // Placements

    /**
     * Main panel contains one or two complete diagrams
     * depending on current view mode activated.
     *
     * Main panel consists of one or tow full diagrams, their description labels
     * and bottom label used for letting users know important events or show
     * short description messages invoked by mouse pointer movements.
     */
    public static final boolean INSIDE_MAIN_PANEL       = false;
    
    /**
     * Top panel shows thumbnails of entries, these entries
     * could be dragged and dropped into main panel.
     *
     * Number of thumbnail positions used depends of recent size of window.
     */
    public static final boolean INSIDE_TOP_PANEL        = true;

    
    // Placement positions
    
    /**
     * Insertion of elements before the other existing ones.
     */
    public static final boolean INSERT_BEFORE           = true;
    
    /**
     * There is sometimes necessary to position element at first place.
     */
    public static final int     FIRST_POSITION          = 0;
    
    
    // Numerology style of characteristics
    
    /**
     * Subdirectory for saving styles.
     */
    public static final String stylesDirectory          = "styles";

    /**
     * Default czech style of characteristics.
     */
    public static final String defaultStyleName         = "shine_cs";

    /**
     * Style files have their standard suffix.
     */
    public static final String styleFileSuffix          = "style";


    // GUI events

    /**
     * Events connected with items.
     * 
     * @author Tomas Psika
     */
    public enum ItemEvents
    {
        /**
         * Selecting item, usually by double-clicking the diagram.
         */
        EVENT_ITEM_SELECTION,
        
        /**
         * Item's entry change event. Usually caused by change of input string.
         */
        EVENT_ENTRY_CHANGED
    }


    // Internet links

    /**
     * Project's website.
     */
    public static final String PROJECT_URL                      = "http://www.psika.cz/software/numerist";

    /**
     * Project support. Relative URL to website of project.
     */
    public static final String PROJECT_SUPPORT_RELATIVE_URL     = "/support";
    
    /**
     * Incrementing or decrementing various things 
     */
    public static boolean INCREMENT = true, DECREMENT = false;
}

