package cz.psika.numerist;

import java.awt.Dimension;

import java.util.ArrayList;

/**
 * Diagram canvas without content and with black background
 * lets user know that it is empty.
 *
 * @author Tomas Psika
 */
public class EmptyDiagram extends Diagram
{
    /* We normally use max 2 empty diagrams within application */
    private static final ArrayList<EmptyDiagram> freeDiagrams;
    
    /* Empty diagram dimension */
    protected static final Dimension DIAGRAM_DIMENSION;

    static
    {
        freeDiagrams = new ArrayList<EmptyDiagram>(2);
        DIAGRAM_DIMENSION = new Dimension(2 * ApplicationWindow.THUMBNAIL_SIZE, 2 * ApplicationWindow.THUMBNAIL_SIZE);
    }
    
    /**
     * Get re-usable instances of this class
     * @param number order number of instance
     * @return instance of empty diagram
     */
    public static final EmptyDiagram getInstance(final int number)
    {
        EmptyDiagram tDiagram;
        try 
        {
            tDiagram = freeDiagrams.get(number);
            tDiagram.setNewSize( ApplicationWindow.getInstance().getDiagramDimension(Constants.FULL_DIAGRAM) );
        }
        catch (IndexOutOfBoundsException e)
        {
            freeDiagrams.add( number, tDiagram = new EmptyDiagram() );
        }
        
        return tDiagram;
    }

    /**
     * Constructor creates blank canvas with black background with 2 x thumbnail size. Nothing else.
     */
    public EmptyDiagram()
    {
        super();
    }

    /* Empty implementation of Memento interface */
    @Override public Memento createMemento() { return null; }
    @Override public void setMemento(Memento memento) {}
}
