package cz.psika.numerist;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

import java.util.Iterator;
import java.util.Vector;

/**
 * File operations.
 *
 * @author Tomas Psika
 */
public final class FileManager
{
    /**
     * Singleton instance of file manager.
     */
    private static FileManager manager;
    
    /**
     * Current file.
     */
    private String currentFile;
    
    /**
     * File modified flag.
     */
    private boolean modified;
    
    /**
     * Returns singleton instance.
     *
     * @return get single static instance of file manager
     */
    public static FileManager getInstance()
    {
        if (manager == null)
            manager = new FileManager();
        
        return manager;
    }
    
    /**
     * Simple private constructor.
     */
    private FileManager()
    {
        currentFile = null;
        modified = false;
    }

    /**
     * Read content of file.
     *
     * @param filename
     * @return vector of all lines read
     * @throws FileNotFoundException if file could not be found
     * @throws IOException on i/o error
     */
    public Vector<String> loadFile(final String filename) throws FileNotFoundException, IOException
    {
        /* Load lines from file */
        final BufferedReader reader = new BufferedReader( new FileReader(filename) );
        final Vector<String> lines = new Vector<String>();
        String line;
        while ( (line = reader.readLine()) != null )
            lines.add(line);
        reader.close();
        
        /* Change current file */
        currentFile = new String(filename);
        
        return lines;
    }

    /**
     * Saving current file.
     *
     * @throws IOException on i/o error
     */
    public void saveFile() throws IOException
    {
        saveFileAs(currentFile);
        setFileModifiedFlag(Constants.FILE_NOT_MODIFIED);
    }
    
    /**
     * Saving file content.
     *
     * @param filename
     * @throws IOException on i/o error
     */
    public void saveFileAs(final String filename) throws IOException
    {
        final BufferedWriter writer = new BufferedWriter( new FileWriter(filename) );
        final Iterator<Item> iterator = Manager.getInstance().itemsIterator();
        while ( iterator.hasNext() )
        {
            writer.write( iterator.next().fetchEntry().getSourceString() );
            writer.newLine();
        }
        writer.close();
    }
    
    /**
     * Set current file.
     *
     * @param filename filename to set or <code>null</code> when we need to clear the file buffer
     */
    public final void setCurrentFilename(final String filename)
    {
        currentFile = (filename == null) ? null : new String(filename);
    }
    
    /**
     * Get current file.
     *
     * @return filename or <code>null</code> if file not set
     */
    public final String getCurrentFilename()
    {
        return (currentFile == null) ? null : new String(currentFile);
    }
    
    /**
     * Change of file modified status flag.
     *
     * @param modifiedFlag modified status flag
     */
    public final void setFileModifiedFlag(final boolean modifiedFlag)
    {
        modified = modifiedFlag;
    }
    
    /**
     * Find out if file was modified.
     *
     * @return <code>true</code> on file changes unsaved
     */
    public final boolean fileModified()
    {
        return modified;
    }
}
