package cz.psika.numerist;

/**
 * Internal interface for all entries and diagrams.
 *
 * All object implementing this interface are observable 
 * and could save or load their history status.
 *
 * @author Tomas Psika
 */
public interface Item extends History, ItemObservable
{
    /**
     * Creates diagram from entry or returns existing object instance
     * of class derived from <code>DiagramCanvas</code>.
     *
     * Implementations of this method are just for possible internal use,
     * should not be part of production release if really not needed.
     * Not compiled and prepared for possible later use.
     *
     * @param thumbnail <code>true</code> if we want thumbnail size of diagram
     * @return object representing diagram
     */
    //public DiagramCanvas fetchDiagram(final boolean wantThumbnail);
    
    /**
     * Get entry representing the diagram or current <code>Entry</code> object.
     *
     * Beware of that the object returned is always original, not just copy.
     * This method is called often, so we need direct access to instance.
     * 
     * Whenever you need copy of the object, implement that functionality 
     * elsewhere out of this interface.
     *
     * @return <code>Entry</code> object
     */
    public Entry fetchEntry();
}
