package cz.psika.numerist;

/**
 * Item history object.
 * 
 * @author Tomas Psika
 */
public class ItemMemento extends Memento implements Item
{
    /**
     * Internal entry identifier.
     */
    protected Integer id;
    
    /**
     * Source string.
     */
    protected String sourceString;
    
    /**
     * Style.
     */
    protected Style style;
    
    /**
     * Constructor.
     * 
     * Initializes style to default application style.
     */
    protected ItemMemento()
    {
        id = null;
        sourceString = null;
        style = StyleManager.getCurrentStyle();
    }
    
    /**
     * Set source string.
     *
     * @param itemString source string (not truncated)
     */
    protected void setString(final String itemString)
    {
        sourceString = new String(itemString);
    }
    
    /**
     * Get source string.
     *
     * @return copy of source string
     */
    protected String getString()
    {
        return new String(sourceString);
    }
    
    /**
     * Set style for the entry.
     *
     * @param itemStyle style to set
     */
    protected void setStyle(final Style itemStyle)
    {
        style = itemStyle;
    }
    
    /**
     * Get entry's style.
     *
     * @return entry's current style
     */
    protected Style getStyle()
    {
        return style;
    }
    
    /**
     * Copy identifier from original <code>Item</code> object.
     *
     * Be very careful about use of this method. 
     * Dont assign existing identifiers to different entries.
     *
     * @param identifier internal identifier
     */
    protected void copyId(final int identifier)
    {
        id = identifier;
    }
    
    /**
     * Get internal identifier.
     *
     * @return internal identifier
     */
    protected Integer getId()
    {
        return new Integer(id);
    }

    /* Item interface implemented within childs and parent interface,
       not good to implement it here, dummy implementation provided */
    public DiagramCanvas fetchDiagram(boolean thumbnail) { return null; }
    @Override public Entry fetchEntry() { return null;}
    @Override public Memento createMemento() { return null; }
    @Override public void setMemento(Memento memento) {}

    /* Empty observer interface implementation */
    @Override public void addObserver(ItemObserver observer) {}
    @Override public void deleteObserver(ItemObserver observer) {}
    @Override public void notifyObservers(Constants.ItemEvents event) {}
}
