package cz.psika.utils;

import java.lang.reflect.Method;

/**
 * Launching browser made as simple as possible
 *
 * Inspired by "Bare Bones Browser Launch"
 * publicated on http://www.java2s.com/Code/Java/Development-Class/LaunchBrowserinMacLinuxUnix.htm
 * and provided as public domain software
 * Date: December 10, 2005
 * Version: 1.5
 * 
 * @author Tomas Psika
 */
public class BrowserLauncher
{
    /**
     * Platform dependent behaviour
     *
     * Unix systems (Linux, SunOS and others): Try to find relevant browsers with standard 'which' utility and launch it
     *      Browser preference: Firefox, Seamonkey's 'iceweasel', Konqueror, Mozilla, Netscape, Opera, Epiphany, Galeon
     * Windows: Use rundll32 service library to load default client's browser
     * Mac OS: Use reflection to load com.apple.eio.FileManager platform-dependent class
     * 
     * @param url requested internet address
     * @return <code>false</code> on any error
     */
    public static final boolean launchURL(String url)
    {
        String osName = System.getProperty("os.name");
        try 
        {
            if (osName.startsWith("Windows"))
            {
                /* Windows XP */
                Runtime.getRuntime().exec("rundll32 url.dll,FileProtocolHandler " + url);
                return true;
            }
            else if (osName.startsWith("Mac OS")) 
            {
                /* Mac OS (X) */
                Class<?> fileMgr = Class.forName("com.apple.eio.FileManager");
                Method openURL = fileMgr.getDeclaredMethod("openURL", new Class[] {String.class});
                openURL.invoke(null, new Object[] {url});
                return true;
            }
            else 
            { 
                /* Unix systems */
                String browser = null;
                String[] browsers = {"firefox", "iceweasel", "konqueror", "mozilla", "netscape", "opera", "epiphany", "galeon"};
                for (int count = 0; count < browsers.length && browser == null; count++)
                {
                    if (Runtime.getRuntime().exec( new String[] {"which", browsers[count]}).waitFor() == 0)
                        browser = browsers[count];
                }
                
                if (browser == null)
                   throw new Exception();
                
                Runtime.getRuntime().exec(new String[] {browser, url});
                
                /* Invoked successfully */
                return true;
             }
        }
        catch (Exception e) 
        {
            System.err.println("could not invoke browser session: " + e.getMessage());
        }
        
        return false;
    }
}

