package cz.psika.utils;

/**
 * Some system-dependent code.
 * 
 *  @author Tomas Psika
 */
public class SystemUtils
{
    /**
     * Windows is supported, but not considered target platform.
     */
    private static final boolean isWindows;
    
    /**
     * Linux/Unix well supported.
     */
    private static final boolean isSupportedUnix;
    
    static
    {
        final String osName = System.getProperty("os.name");
        
        /* Windows */
        isWindows = (osName.startsWith("Windows")) ? true : false;
        
        /* Supported Unix systems */
        isSupportedUnix = (osName.equals("Linux")
                || osName.equals("FreeBSD") 
                || osName.startsWith("Mac OS")
                || osName.equals("HP UX")
                || osName.equals("Solaris") || osName.equals("SunOS")) ? true : false;
    }
    
    /**
     * Windows running ?
     * 
     * @return <code>true</code> when running on Windows systems
     */
    public static final boolean runningOnWindows() 
    {
        return isWindows; 
    }
    
    /**
     * Linux/Unix running ?
     * 
     * @return <code>true</code> if running on unix-like operating system
     */
    public static final boolean runningOnSupportedUnix()
    {
        return isSupportedUnix;
    }

    /**
     * Return type of OS as flag
     * 
     * @return string constant, 'U' means supported Unix system, 'W' means Windows, null none of these
     */
    public static final String getOSTypeFlag()
    {
        if (isSupportedUnix)
            return "U";
        else if (isWindows)
            return "W";
        else
            return null;
    }
}


