package cz.psika.utils;

import java.util.ArrayList;

/**
 * Extended ArrayList class to hold unique values only.
 *
 * Use method 'add' only, which is safe enough, some other methods should be overloaded
 * to achieve proper extended functionality.
 *
 * Code retrieved from dangertree techblog (http://weblog.dangertree.net/2007/06/09/unique-arraylist/)
 * and slightly modified to make it compilable and as much simple as possible.
 * 
 * @param <T> list item type
 * @author Tomas Psika
 */
public class UniqueArrayList<T> extends ArrayList<T> 
{
    /**
     * Add the object to the list if there is no other copy of it.
     * 
     * Values of type <code>null</code> are ignored.
     * 
     * @param obj item of list
     * @return <code>true</code> on success, <code>false</code> when item already exists in the list or <code>null</code> value given
     */
    @Override
    public boolean add(T obj)
    {
        if (obj == null)
            return false;
        
        for (int i=0; i<size(); i++)
            if ( obj.equals(get(i)) )
                return false;
        
        return super.add(obj);
    }
}
